""" st7735r_128x160_colored_labels.py

This test will initialize the display using displayio and draw 8 colored
labels. Useful for testing the color settings on an unknown display.
The original program was slightly modified and adapted for the ST32F411CE
blackpill board.

Link: https://github.com/adafruit/Adafruit_CircuitPython_ST7735R/blob/main/examples/
"""

import board
import busio
import terminalio
import displayio
from adafruit_display_text import label
from adafruit_st7735r import ST7735R

# Release any resources currently in use for the displays
displayio.release_displays()

# create the spi device and pins we will need
spi = busio.SPI(board.B13, MOSI=board.B15, MISO=board.B14)
tft_cs = board.B12
tft_dc = board.B1
tft_rst = board.B0
display_bus = displayio.FourWire(spi, command=tft_dc, chip_select=tft_cs, reset=tft_rst)
display = ST7735R(display_bus, width=128, height=160, rotation=0, bgr=True)

# Make the display context
splash = displayio.Group()
display.show(splash)

# write some text in each font color, rgb, cmyk
text_group_left = displayio.Group(scale=1, x=10, y=10)
text_area_red = label.Label(terminalio.FONT, text="RED", color=0xFF0000)
text_area_green = label.Label(terminalio.FONT, text="\nGREEN", color=0x00FF00)
text_area_blue = label.Label(terminalio.FONT, text="\n\nBLUE", color=0x0000FF)
text_area_white = label.Label(terminalio.FONT, text="\n\n\nWHITE", color=0xFFFFFF)
text_group_left.append(text_area_red)
text_group_left.append(text_area_green)
text_group_left.append(text_area_blue)
text_group_left.append(text_area_white)
splash.append(text_group_left)

text_group_right = displayio.Group(scale=1, x=74, y=10)
text_area_cyan = label.Label(terminalio.FONT, text="CYAN", color=0x00FFFF)
text_group_right.append(text_area_cyan)
text_area_magenta = label.Label(terminalio.FONT, text="\nMAGENTA", color=0xFF00FF)
text_group_right.append(text_area_magenta)
text_area_yellow = label.Label(terminalio.FONT, text="\n\nYELLOW", color=0xFFFF00)
text_group_right.append(text_area_yellow)
text_area_black = label.Label(terminalio.FONT, text="\n\n\nGREY", color=0x808080)
text_group_right.append(text_area_black)
splash.append(text_group_right)

while True:
    pass