"""
This is the official example of the Adafruit_display_shapes library, but
the coordinates were scaled down in order to fit into the 160x128 pixel
screen of the 1.8" ST7735 display module. 
Landscape mode is used (i.e. rotation = 90)
"""
import board
import busio
import displayio
from adafruit_st7735r import ST7735R
from adafruit_display_shapes.rect import Rect
from adafruit_display_shapes.circle import Circle
from adafruit_display_shapes.roundrect import RoundRect
from adafruit_display_shapes.triangle import Triangle
from adafruit_display_shapes.line import Line
from adafruit_display_shapes.polygon import Polygon

# Release any resources currently in use for the displays
displayio.release_displays()

# create the spi device and pins we will need
spi = busio.SPI(board.B13, MOSI=board.B15)
display_bus = displayio.FourWire(spi, command=board.B1, chip_select=board.B12, reset=board.B0)
display = ST7735R(display_bus, width=160, height=128, rotation=90, bgr=True)

# Make the display context
splash = displayio.Group()
display.show(splash)

# Make a background color fill
color_bitmap = displayio.Bitmap(160, 128, 1)
color_palette = displayio.Palette(1)
color_palette[0] = 0xFFFFFF
bg_sprite = displayio.TileGrid(color_bitmap, x=0, y=0, pixel_shader=color_palette)
splash.append(bg_sprite)
##########################################################################

splash.append(Line(110,  65, 135, 105, 0xFF0000))
splash.append(Line(135, 105, 110, 105, 0xFF0000))
splash.append(Line(110, 105, 135,  65, 0xFF0000))
splash.append(Line(135,  65, 110,  65, 0xFF0000))

# Draw a blue star
polygon = Polygon(
    [
        (127, 20),
        (131, 31),
        (142, 31),
        (132, 38),
        (137, 50),
        (127, 42),
        (117, 50),
        (122, 38),
        (112, 31),
        (124, 31),
    ],
    outline=0x0000FF,
)
splash.append(polygon)

triangle = Triangle(85, 25, 60, 70, 105, 80, fill=0x00FF00, outline=0xFF00FF)
splash.append(triangle)

rect = Rect(40, 10, 21, 21, fill=0x0000FF)
splash.append(rect)

circle = Circle(50, 50, 10, fill=0x00FF00, outline=0xFF00FF)
splash.append(circle)

rect2 = Rect(25, 64, 31, 41, outline=0x0, stroke=3)
splash.append(rect2)

roundrect = RoundRect(5, 5, 31, 41, 8, fill=0xFFFF00, outline=0xFF00FF, stroke=3)
splash.append(roundrect)


while True:
    pass