'''
  https://learn.adafruit.com/circuitpython-display-support-using-displayio/sprite-sheet
  The original example was slightly modified in order to show how to change the position
  of the sprite
'''
import board
import busio
import displayio
import time
from adafruit_st7735r import ST7735R

# Release any resources currently in use for the displays
displayio.release_displays()

# create the spi device and pins we will need
spi = busio.SPI(board.B13, MOSI=board.B15)
display_bus = displayio.FourWire(spi, command=board.B1, chip_select=board.B12, reset=board.B0)
display = ST7735R(display_bus, width=128, height=160, rotation=0, bgr=True)

# Make the display context
splash = displayio.Group()
display.show(splash)

# Load the sprite sheet (bitmap)
sprite_sheet = displayio.OnDiskBitmap("/cp_sprite_sheet.bmp")

# Create a sprite (tilegrid)
sprite = displayio.TileGrid(sprite_sheet, pixel_shader=sprite_sheet.pixel_shader,
                            width = 1,
                            height = 1,
                            tile_width = 16,
                            tile_height = 16)

# Create a Group to hold the sprite
group = displayio.Group(scale=2)

# Add the sprite to the Group
group.append(sprite)
splash.append(group)

# Set sprite location
group.x = 60
group.y = 120

# Loop through each sprite in the sprite sheet
source_index = 0

while True:
    sprite[0] = source_index % 6
    source_index += 1
    group.x = 20 + (source_index % 6)*10
    group.y = 20 + (source_index % 6)*16
    time.sleep(2)