"""
Simple slideshow example. The images should be BMP files placed into the /images directory.
"""
import board
import busio
import displayio
import time
from adafruit_st7735r import ST7735R
from adafruit_slideshow import PlayBackOrder, SlideShow

# Release any resources currently in use for the displays
displayio.release_displays()

# create the spi device and pins we will need
spi = busio.SPI(board.B13, MOSI=board.B15)
display_bus = displayio.FourWire(spi, command=board.B1, chip_select=board.B12, reset=board.B0)
display = ST7735R(display_bus, width=128, height=160, rotation=0, bgr=True)

# Create the slideshow object that plays through once alphabetically.
slideshow = SlideShow(display,
                      folder="/images",
                      loop=True,
                      order=PlayBackOrder.ALPHABETICAL,
                      dwell=5)

while slideshow.update():
    pass